@@ -1,6 +1,6 @@
   /*
 
-  knetfilter v 1.2.2
+  knetfilter v 2.0.0
 
   Copyright (C) 2000 Luigi Genoni
   		     venom@DarkStar.sns.it
@@ -16,10 +16,6 @@
 #include <qstrlist.h>
 #include <strings.h>
 
-#include <kmsgbox.h>
-#include <kiconloader.h>
-#include <klocale.h>
-
 #include "knat.h"
 
 
